@@ -112,3 +112,11 @@ def scatter_2d(x_list, y_list):
     plt.title(f"{x_name} vs {y_name}")
 
     return plt
+
+
+def drag_force_2d(velocity: VariableList2D, rho, C, A):
+    vMag = velocity.magnitude
+    vHat = velocity / vMag  # direction of velocity
+
+    Fdrag = (1 / 2) * rho * (vMag**2) * C * A * vHat
+    return Fdrag
